Crate farmap

Crate farmap 

Farmap

A library to parse and analyze farcaster data. The ambition is to be the simplest gateway to farcaster data for your rust application. For now, the library is focused on Warpcast Spam Labels and farcaster protocol data via Pinata, but other types of data may be added in the future.

Quickstart

In order to get started, you likely want to fetch data using the fetch module. Choose one or several Fetchers to get the data you want. You can use and analyze the data in various ways using the User, UserCollection and Subset struct.

Re-exports

pub use spam_score::DatedSpamScoreCount;
pub use spam_score::SpamRecord;
pub use spam_score::SpamScore;
pub use spam_score::SpamScoreCount;
pub use spam_score::SpamScoreDistribution;
pub use user::InvalidInputError;
pub use user::User;
pub use user::UserError;

Modules

fetch
Fetch data from external sources.
fid_score_shift
spam_score
subset
user
user_collection

Structs

FidScoreShift
Fidded
A fid value wrapper.
SetWithCastData
A set of users that contain at least one CastType.
SetWithSpamEntries
A set of UserWithSpamData
UnprocessedUserLine
UserCollection
UserWithCastData
A reference to a User of lifetime a that contains at least one CastType.
UserWithSpamData
A User guaranteed to have at least one SpamUpdate.
UsersSubset

Enums

CastType
InvalidCastInputError

Traits

HasTag
IsUser
A type that references user data.
TryFromUser
Create from IsUser.
TryFromUserSet
Falllibly create one kind of UserSet from another.
UserSet
UserValue