pub struct WieldFetcher { /* private fields */ }Expand description
Fetches data from the wield api. The fetcher likely won’t work without an api key so make sure to follow their docs to get an api_key and set set_api_key_from_env_var method to set your api key before trying to use this struct to make calls. You also need to build before using.
Implementations
Sourceimpl WieldFetcher
impl WieldFetcher
pub fn set_api_key_from_env_var( self, api_key_var: &str, ) -> Result<Self, ApiKeyError>
pub fn build(self) -> Result<Self, BuildError>
pub async fn fetch_followers(&self, fid: u64) -> Result<Vec<u64>, ImporterError>
pub async fn fetch_follower_response_for_fid( &self, fid: u64, ) -> Result<Response, ImporterError>